@@ -33,7 +33,7 @@ def install_package(pkg: str,
                     buildtype: str,
                     jobs: int,
                     reconfigure=False, 
-                    build_only=False):
+                    no_deps=False):
     
     """
     Fetch a recipe file from the default path using the given package name, 
@@ -57,8 +57,9 @@ def install_package(pkg: str,
     # install dependencies if not found
     for dep in pkg.depends:
 
-        # if build only, skip the loop!
-        if build_only:
+        # if no-deps mode, skip the loop!
+        if no_deps:
+            pprint('skipping dependencies')
             break
         
         # try to find-package this dependency
@@ -94,11 +95,10 @@ def install_package(pkg: str,
             pprint(f'depends on {dep} -> found')
     
     # use the fetcher! (if not build only)
-    if not build_only:
-        srcdir = os.path.join(srcroot, pkg.name)
-        if not pkg.fetcher.fetch(srcdir):
-            pprint('failed to fetch package')
-            return False 
+    srcdir = os.path.join(srcroot, pkg.name)
+    if not pkg.fetcher.fetch(srcdir):
+        pprint('failed to fetch package')
+        return False 
     
     # configure and build
     ok = build_package(pkg=pkg, 
@@ -115,10 +115,10 @@ def install_package(pkg: str,
     return ok
 
 
-def write_setup_file(installdir):
+def write_setup_file(srcdir, installdir):
     
     """
-    Write a setup file to the given installdir directory.
+    Write a setup file to the root directory.
     """
 
     this_dir = os.path.dirname(os.path.abspath(__file__))
@@ -126,8 +126,9 @@ def write_setup_file(installdir):
     with open(setup_template, 'r') as f:
         content = f.read()
         content = content.replace('£PREFIX£', os.path.realpath(installdir))
+        content = content.replace('£SRCDIR£', os.path.realpath(srcdir))
     
-    setup_file = os.path.join(installdir, 'setup.bash')
+    setup_file = os.path.join(installdir, '..', 'setup.bash')
     if not os.path.exists(setup_file):
         with open(setup_file, 'w') as f:
             f.write(content)
@@ -136,7 +137,7 @@ def write_setup_file(installdir):
 def check_ws_file(rootdir):
     
     """
-    Write a hidden file to mark the forest root directory
+    Check forest marker file exists
     """
 
     ws_file = os.path.join(rootdir, '.forest')
